Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type JSONStats ¶
type JSONStats struct {
Stats
}
JSONStats is what we want to report as stats via http
type Server ¶
type Server interface {
// Reset atomically sets all the counters to 0
Reset()
SetCounter(key string, val int64)
UpdateCounterBy(key string, count int64)
}
Server is a stats server interface
type Stats ¶
type Stats struct {
// contains filtered or unexported fields
}
Stats is an implementation of
func (Stats) SetCounter ¶
SetCounter will set a counter to the provided value.
func (Stats) UpdateCounterBy ¶
UpdateCounterBy will increment counter
Click to show internal directories.
Click to hide internal directories.